Rule class abstract

Implementers
Annotations

Constructors

Rule()
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
type → RuleType
no setter

Methods

apply(Document document, int index, {int? len, Object? data, Attribute? attribute}) → Delta?
applyRule(Document document, int index, {int? len, Object? data, Attribute? attribute}) → Delta?
Applies heuristic rule to an operation on a document and returns resulting Delta.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited
validateArgs(int? len, Object? data, Attribute? attribute) → void

Operators

operator ==(Object other) → bool
The equality operator.
inherited